import { AxiosRequestConfig } from 'axios';
import { LaunchOptions } from 'puppeteer';

declare enum EngineType {
    Html = "html",
    Spa = "spa",
    Json = "json",
    Xml = "xml"
}
type EngineTypes = "html" | "spa" | "json" | "xml";
declare enum OperationType {
    Difference = "difference",
    Equal = "equal",
    Contains = "contains",
    Regex = "regex"
}
type OperationTypes = "difference" | "equal" | "contains" | "regex";
type OperatorFn = (a: string, b: string, sensitive: boolean) => boolean;
type Operators = {
    [key: string]: OperatorFn;
};
type TScrapedData = Record<string, any>;
type TScrapedDataPromise = Promise<TScrapedData>;
interface Condition {
    value: string;
    operation: EngineType | OperationTypes;
    sensitive?: boolean;
}
interface ISelector {
    selector: string;
    attribute?: string;
    conditions?: Condition[];
}
type TSelectors = Record<string, ISelector>;
interface IScrapeHtmlOptions {
    selectors: TSelectors;
    request?: AxiosRequestConfig;
}
interface IScrapeSpaOptions {
    selectors: TSelectors;
    request?: LaunchOptions;
}
interface IScrapeJsonOptions {
    selectors: TSelectors;
    request?: AxiosRequestConfig;
}
interface IScrapeXmlOptions {
    selectors: TSelectors;
    request?: AxiosRequestConfig;
}
interface IScrapeOptions {
    url: string;
    engine: EngineType | EngineTypes;
    options: IScrapeHtmlOptions & IScrapeSpaOptions & IScrapeJsonOptions & IScrapeXmlOptions;
}

declare const scrape: ({ url, engine, options, }: IScrapeOptions) => TScrapedDataPromise;

declare const scrapeHtml: (url: string, { selectors, request }: IScrapeHtmlOptions) => TScrapedDataPromise;

declare const scrapeSpa: (url: string, { selectors, request }: IScrapeSpaOptions) => TScrapedDataPromise;

declare const scrapeXml: (url: string, { selectors, request }: IScrapeXmlOptions) => TScrapedDataPromise;

declare const scrapeJson: (url: string, { selectors, request }: IScrapeXmlOptions) => TScrapedDataPromise;

export { Condition, EngineType, EngineTypes, IScrapeHtmlOptions, IScrapeJsonOptions, IScrapeOptions, IScrapeSpaOptions, IScrapeXmlOptions, ISelector, OperationType, OperationTypes, OperatorFn, Operators, TScrapedData, TScrapedDataPromise, TSelectors, scrape, scrapeHtml, scrapeJson, scrapeSpa, scrapeXml };
